@@ -19,6 +19,7 @@ import functools
 from oslo_utils import timeutils
 
 from taskflow.engines.action_engine import executor
+from taskflow.engines.worker_based import dispatcher
 from taskflow.engines.worker_based import protocol as pr
 from taskflow.engines.worker_based import proxy
 from taskflow.engines.worker_based import types as wt
@@ -44,10 +45,8 @@ class WorkerTaskExecutor(executor.TaskExecutor):
         self._requests_cache = wt.RequestsCache()
         self._transition_timeout = transition_timeout
         type_handlers = {
-            pr.RESPONSE: [
-                self._process_response,
-                pr.Response.validate,
-            ],
+            pr.RESPONSE: dispatcher.Handler(self._process_response,
+                                            validator=pr.Response.validate),
         }
         self._proxy = proxy.Proxy(uuid, exchange,
                                   type_handlers=type_handlers,
@@ -62,7 +61,8 @@ class WorkerTaskExecutor(executor.TaskExecutor):
         # pre-existing knowledge of the topics those workers are on to gather
         # and update this information).
         self._finder = wt.ProxyWorkerFinder(uuid, self._proxy, topics)
-        self._finder.on_worker = self._on_worker
+        self._finder.notifier.register(wt.WorkerFinder.WORKER_ARRIVED,
+                                       self._on_worker)
         self._helpers = tu.ThreadBundle()
         self._helpers.bind(lambda: tu.daemon_thread(self._proxy.start),
                            after_start=lambda t: self._proxy.wait(),
@@ -74,8 +74,9 @@ class WorkerTaskExecutor(executor.TaskExecutor):
                                after_join=lambda t: p_worker.reset(),
                                before_start=lambda t: p_worker.reset())
 
-    def _on_worker(self, worker):
+    def _on_worker(self, event_type, details):
         """Process new worker that has arrived (and fire off any work)."""
+        worker = details['worker']
         for request in self._requests_cache.get_waiting_requests(worker):
             if request.transition_and_log_error(pr.PENDING, logger=LOG):
                 self._publish_request(request, worker)
